@@ -385,7 +385,8 @@ impl<C: Copy + Zero + Signed + Eq + Ord + Bounded> EdmondsKarp<C> for SparseCapa
                 ns.into_iter()
                     .filter_map(|(&n, &c)| if c > Zero::zero() { Some((n, c)) } else { None })
                     .collect()
-            }).unwrap_or_else(Vec::new)
+            })
+            .unwrap_or_else(Vec::new)
     }
 
     fn residual_capacity(&self, from: usize, to: usize) -> C {
@@ -408,7 +409,8 @@ impl<C: Copy + Zero + Signed + Eq + Ord + Bounded> EdmondsKarp<C> for SparseCapa
                         None
                     }
                 })
-            }).collect()
+            })
+            .collect()
     }
 
     fn add_flow(&mut self, from: usize, to: usize, capacity: C) {
@@ -431,7 +433,8 @@ impl<C: Copy + Zero + Signed + Eq + Ord + Bounded> EdmondsKarp<C> for SparseCapa
                 ns.iter()
                     .filter_map(|(&o, &c)| if c > Zero::zero() { Some(o) } else { None })
                     .collect()
-            }).unwrap_or_else(Vec::new)
+            })
+            .unwrap_or_else(Vec::new)
     }
 }
 
@@ -500,7 +503,8 @@ impl<C: Copy + Zero + Signed + Ord + Bounded> EdmondsKarp<C> for DenseCapacity<C
                 } else {
                     None
                 }
-            }).collect()
+            })
+            .collect()
     }
 
     fn residual_capacity(&self, from: usize, to: usize) -> C {
@@ -520,7 +524,8 @@ impl<C: Copy + Zero + Signed + Ord + Bounded> EdmondsKarp<C> for DenseCapacity<C
                 } else {
                     None
                 }
-            }).collect()
+            })
+            .collect()
     }
 
     fn add_flow(&mut self, from: usize, to: usize, capacity: C) {
@@ -536,13 +541,7 @@ impl<C: Copy + Zero + Signed + Ord + Bounded> EdmondsKarp<C> for DenseCapacity<C
 
     fn flows_from(&self, from: usize) -> Vec<usize> {
         (0..self.common.size)
-            .filter_map(|to| {
-                let flow = self.flow(from, to);
-                if flow > Zero::zero() {
-                    Some(to)
-                } else {
-                    None
-                }
-            }).collect()
+            .filter(|to| self.flow(from, *to) > Zero::zero())
+            .collect()
     }
 }
